aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lisp/mastodon-views.el11
1 files changed, 6 insertions, 5 deletions
diff --git a/lisp/mastodon-views.el b/lisp/mastodon-views.el
index 97ef082..9c016c3 100644
--- a/lisp/mastodon-views.el
+++ b/lisp/mastodon-views.el
@@ -733,22 +733,23 @@ INSTANCE is an instance domain name."
(mastodon-views--instance-response-fun response brief instance))
(mastodon-tl--do-if-toot
(let* ((toot (if (mastodon-tl--profile-buffer-p)
;; we may be on profile itself:
(or (mastodon-tl--property 'profile-json)
;; or on profile account listings, which use toot-json:
;; or just toots:
(mastodon-tl--property 'toot-json))
- ;; normal timeline:
+ ;; normal timeline/account listing:
(mastodon-tl--property 'toot-json)))
(reblog (alist-get 'reblog toot))
(account (or (alist-get 'account reblog)
- (alist-get 'account toot)))
+ (alist-get 'account toot)
+ toot)) ; else `toot' is already an account listing.
;; we can't use --profile-buffer-p as our test here because we may
- ;; be looking at toots/boosts/users in a profile buffer
+ ;; be looking at toots/boosts/users in a profile buffer.
;; profile-json works as a defacto test for if point is on the
;; profile details at the top of a profile buffer.
(url (if (mastodon-tl--property 'profile-json)
- (alist-get 'url toot) ; profile
+ (alist-get 'url toot) ; profile description
(alist-get 'url account)))
(username (if (mastodon-tl--property 'profile-json)
(alist-get 'username toot) ;; profile
@@ -733,22 +733,23 @@ INSTANCE is an instance domain name."
(mastodon-tl--do-if-toot
(let* ((toot (if (mastodon-tl--profile-buffer-p)
- ;; we may be on profile itself:
+ ;; we may be on profile description itself:
(or (mastodon-tl--property 'profile-json)
;; or on profile account listings, which use toot-json: